rnalysis.filtering.FoldChangeFilter.majority\_vote\_intersection
================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.majority_vote_intersection